@@ -68,25 +68,25 @@ int option_set_usesyslog_alpm(PyObject *self, PyObject *value, void* closure)
   return 0;
 }
 
-PyObject* option_get_usedelta_alpm(PyObject *self, void* closure) {
+PyObject* option_get_deltaratio_alpm(PyObject *self, void* closure) {
   alpm_handle_t *handle = ALPM_HANDLE(self);
-  int ret = alpm_option_get_usedelta(handle);
+  double ret = alpm_option_get_deltaratio(handle);
   if (ret == -1) {
-    RET_ERR("failed getting usedelta", alpm_errno(handle), NULL);
+    RET_ERR("failed getting deltaratio", alpm_errno(handle), NULL);
   } else
-    return PyLong_FromLong(ret);
+    return PyFloat_FromDouble(ret);
 }
 
-int option_set_usedelta_alpm(PyObject *self, PyObject *value, void* closure)
+int option_set_deltaratio_alpm(PyObject *self, PyObject *value, void* closure)
 {
   alpm_handle_t *handle = ALPM_HANDLE(self);
-  if(!PyLong_Check(value))
-  {
-    PyErr_SetString(PyExc_TypeError, "wrong arguments");
+  double fval = PyFloat_AsDouble(value);
+
+  if(PyErr_Occurred()) {
     return -1;
   }
 
-  alpm_option_set_usedelta(handle, PyLong_to_int(value, -1));
+  alpm_option_set_deltaratio(handle, fval);
   return 0;
 }
 
@@ -334,7 +334,11 @@ extern PyObject *global_py_callbacks[N_CALLBACKS];
 void pyalpm_logcb(alpm_loglevel_t level, const char *fmt, va_list va_args) {
   char *log;
   PyObject *result;
-  vasprintf(&log, fmt, va_args);
+  int ret;
+
+  ret = vasprintf(&log, fmt, va_args);
+  if(ret == -1)
+    log = "pyalpm_logcb: could not allocate memory";
   result = PyObject_CallFunction(global_py_callbacks[CB_LOG], "is", level, log);
   if (!result) PyErr_Print();
   Py_CLEAR(result);
